@@ -33,6 +33,8 @@
 #include "profilemanager/intentselector.h"
 #include "util.h"
 #include "config.h"
+#include "gettext.h"
+#define _(x) gettext(x)
 
 #include "dialogs.h"
 
@@ -79,7 +81,6 @@ struct printsetupdata
 	GtkWidget *dialog;
 	stp_vars_t *backupvars;
 	char *olddriver;
-	char *oldcommand;
 	stpui_optionbook_custompage custompage;
 };
 
@@ -109,22 +110,27 @@ static void driver_changed(GtkWidget *wid,gpointer data)
 void PrintSetup_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 {
 	printsetupdata dialogdata;
+
+	cerr << "Opening print setup dialog" << endl;
 	
 	dialogdata.state=&state;
 	dialogdata.backupvars=stp_vars_create_copy(state.printer.stpvars);
 	dialogdata.olddriver=g_strdup(state.printoutput.FindString("Driver"));
-	dialogdata.oldcommand=g_strdup(state.printoutput.FindString("Command"));
-
-	dialogdata.dialog=gtk_dialog_new_with_buttons("Printer Setup",
+	
+	dialogdata.dialog=gtk_dialog_new_with_buttons(_("Printer Setup"),
 		parent,GtkDialogFlags(0),
 		GTK_STOCK_CANCEL,GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OK,GTK_RESPONSE_OK,
 		NULL);
 	gtk_window_set_default_size(GTK_WINDOW(dialogdata.dialog),500,350);
 
+	cerr << "Creating PrintOutput widget..." << endl;
+
 	dialogdata.printoutput=pp_printoutput_new(&state.printoutput);
 	g_object_ref(G_OBJECT(dialogdata.printoutput));
 
+	cerr << "Created PrintOutput widget..." << endl;
+
 	dialogdata.custompage.name="Output";
 	dialogdata.custompage.widget=dialogdata.printoutput;
 	
@@ -139,21 +145,21 @@ void PrintSetup_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 	switch(result)
 	{
 		case GTK_RESPONSE_CANCEL:
+			state.printoutput.DBToQueues();
 			stp_vars_copy(state.printer.stpvars,dialogdata.backupvars);
 			state.printoutput.SetString("Driver",dialogdata.olddriver);
-			state.printoutput.SetString("Command",dialogdata.oldcommand);
 			break;
 		case GTK_RESPONSE_OK:
+			state.printoutput.QueuesToDB();
 			const char *p1=stp_get_string_parameter(dialogdata.backupvars,"PageSize");
 			const char *p2=stp_get_string_parameter(state.printer.stpvars,"PageSize");
-			if(strcmp(p1,p2)!=0)
+			if(p1 && p2 && strcmp(p1,p2)!=0)
 				state.layout->UpdatePageSize();  // Needs to be run every time, but preserve margins.
 			break;
 	}
 	g_object_unref(G_OBJECT(dialogdata.printoutput));
 	stp_vars_destroy(dialogdata.backupvars);
 	g_free(dialogdata.olddriver);
-	g_free(dialogdata.oldcommand);
 	gtk_widget_destroy(dialogdata.dialog);
 }
 
@@ -162,7 +168,7 @@ void PrintSetup_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 
 void About_Dialog(GtkWindow *parent)
 {
-	GtkWidget *dialog=gtk_dialog_new_with_buttons("About",
+	GtkWidget *dialog=gtk_dialog_new_with_buttons(_("About"),
 		parent,GtkDialogFlags(0),
 		GTK_STOCK_OK,GTK_RESPONSE_OK,
 		NULL);
@@ -209,7 +215,7 @@ static void	paths_changed(GtkWidget *widget,gpointer user_data)
 void Paths_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 {
 	GtkWidget *dialog;
-	dialog=gtk_dialog_new_with_buttons("Set paths...",
+	dialog=gtk_dialog_new_with_buttons(_("Set paths..."),
 		parent,GtkDialogFlags(0),
 		GTK_STOCK_CANCEL,GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OK,GTK_RESPONSE_OK,
@@ -234,7 +240,7 @@ void Paths_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 	gtk_widget_show(profilepath);
 	gtk_widget_show(frame);
 
-	label=gtk_label_new("ICC Profiles");
+	label=gtk_label_new(_("ICC Profiles"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(book),frame,label);
 
 
@@ -266,7 +272,7 @@ void Paths_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 
 	g_signal_connect(borderpath,"changed",G_CALLBACK(paths_changed),&dd);
 
-	label=gtk_label_new("Borders");
+	label=gtk_label_new(_("Borders"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(book),frame,label);
 
 	// Background path selector...
@@ -297,7 +303,7 @@ void Paths_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 
 	g_signal_connect(bgpath,"changed",G_CALLBACK(paths_changed),&bgdd);
 
-	label=gtk_label_new("Backgrounds");
+	label=gtk_label_new(_("Backgrounds"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(book),frame,label);
 
 
@@ -325,7 +331,7 @@ char *ImageMask_Dialog(GtkWindow *parent,PhotoPrint_State &state,char *oldfn)
 {
 	char *nfn=oldfn;
 	GtkWidget *dialog;
-	dialog=gtk_dialog_new_with_buttons("Select a border...",
+	dialog=gtk_dialog_new_with_buttons(_("Select a border..."),
 		parent,GtkDialogFlags(0),
 		GTK_STOCK_CANCEL,GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OK,GTK_RESPONSE_OK,
@@ -372,7 +378,7 @@ void ExportTiff_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 {
 	GtkWidget *dialog;
 	GtkWidget *hbox;
- 	dialog=gtk_dialog_new_with_buttons("Export TIFF...",
+ 	dialog=gtk_dialog_new_with_buttons(_("Export TIFF..."),
 		parent,GtkDialogFlags(0),
 		GTK_STOCK_CANCEL,GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OK,GTK_RESPONSE_OK,
@@ -419,7 +425,7 @@ void ExportTiff_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 
 	hbox=gtk_hbox_new(FALSE,0);
 
-	label=gtk_label_new("Page range:");
+	label=gtk_label_new(_("Page range:"));
 	gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,1,2);
 	gtk_widget_show(label);
 
@@ -427,8 +433,8 @@ void ExportTiff_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(pagesentry),TRUE,TRUE,0);
 	gtk_widget_show(pagesentry);
 
-	label=gtk_label_new("   Resolution (dpi):");
-	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(label),TRUE,TRUE,0);
+	label=gtk_label_new(_("Resolution (dpi):"));
+	gtk_box_pack_start(GTK_BOX(hbox),GTK_WIDGET(label),TRUE,TRUE,20);
 	gtk_widget_show(label);
 
 	GtkWidget *resspin=gtk_spin_button_new_with_range(72,2880,1);
@@ -452,7 +458,7 @@ void ExportTiff_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 	gtk_table_attach_defaults(GTK_TABLE(table),outputprof,1,2,3,4);
 	gtk_widget_show(outputprof);
 
-	GtkWidget *profactive=gtk_check_button_new_with_label("Output Profile:");
+	GtkWidget *profactive=gtk_check_button_new_with_label(_("Output Profile:"));
 	g_signal_connect(G_OBJECT(profactive),"toggled",G_CALLBACK(profenable_changed),outputprof);
 	gtk_table_attach_defaults(GTK_TABLE(table),profactive,0,1,3,4);
 	gtk_widget_show(profactive);
@@ -525,7 +531,7 @@ void ExportTiff_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 							ImageSource *is=state.layout->GetImageSource(p-1,CM_COLOURDEVICE_EXPORT,factory,res);
 							if(is)
 							{
-								ProgressBar p("Exporting...",true,GTK_WIDGET(parent));
+								ProgressBar p(_("Exporting..."),true,GTK_WIDGET(parent));
 
 								if(profileactive)
 								{
@@ -546,7 +552,7 @@ void ExportTiff_Dialog(GtkWindow *parent,PhotoPrint_State &state)
 						done=true;
 					}
 					else
-						ErrorMessage_Dialog("No filename provided.",GTK_WIDGET(parent));
+						ErrorMessage_Dialog(_("Please provide a filename."),GTK_WIDGET(parent));
 				}
 				catch (const char *error)
 				{
@@ -563,7 +569,7 @@ char *Background_Dialog(GtkWindow *parent,PhotoPrint_State &state,char *oldfn)
 {
 	char *nfn=oldfn;
 	GtkWidget *dialog;
-	dialog=gtk_dialog_new_with_buttons("Select a background...",
+	dialog=gtk_dialog_new_with_buttons(_("Select a background..."),
 		parent,GtkDialogFlags(0),
 		GTK_STOCK_CANCEL,GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OK,GTK_RESPONSE_OK,
@@ -628,7 +634,7 @@ static void refreshprofiledialog(GtkWidget *wid,gpointer obj)
 	else
 		st->ii->AssignProfile(NULL);
 
-	int intent=intentselector_getintent(INTENTSELECTOR(st->intent));
+	LCMSWrapper_Intent intent=intentselector_getintent(INTENTSELECTOR(st->intent));
 	st->ii->SetRenderingIntent(intent);
 
 	cerr << "Rendering intent: " << intent << endl;
@@ -655,7 +661,7 @@ void SetCustomProfileDialog(GtkWindow *parent,PhotoPrint_State &state,Layout_Ima
 {
 	if(!ii)
 	{
-		ErrorMessage_Dialog("Please select an image first!",GTK_WIDGET(parent));
+		ErrorMessage_Dialog(_("Please select an image first!"),GTK_WIDGET(parent));
 		return;
 	}
 
@@ -677,7 +683,7 @@ void SetCustomProfileDialog(GtkWindow *parent,PhotoPrint_State &state,Layout_Ima
 	char *oldcustomprofile=NULL;
 	if(octmp)
 		oldcustomprofile=strdup(octmp);
-	int oldintent=ii->GetRenderingIntent();
+	LCMSWrapper_Intent oldintent=ii->GetRenderingIntent();
 
 	customprofstate st;
 	st.ii=ii;
@@ -686,7 +692,7 @@ void SetCustomProfileDialog(GtkWindow *parent,PhotoPrint_State &state,Layout_Ima
 	GtkWidget *dialog;
 //	GtkWidget *hbox;
 	GtkWidget *label;
- 	dialog=gtk_dialog_new_with_buttons("Set Custom Profile...",
+ 	dialog=gtk_dialog_new_with_buttons(_("Set Custom Profile..."),
 		parent,GtkDialogFlags(0),
 		GTK_STOCK_CANCEL,GTK_RESPONSE_CANCEL,
 		GTK_STOCK_OK,GTK_RESPONSE_OK,
@@ -698,11 +704,11 @@ void SetCustomProfileDialog(GtkWindow *parent,PhotoPrint_State &state,Layout_Ima
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),table,FALSE,FALSE,5);
 	gtk_widget_show(table);
 
-	label=gtk_label_new("Before:");
+	label=gtk_label_new(_("Before:"));
 	gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,0,1);
 	gtk_widget_show(label);
 
-	label=gtk_label_new("After:");
+	label=gtk_label_new(_("After:"));
 	gtk_table_attach_defaults(GTK_TABLE(table),label,1,2,0,1);
 	gtk_widget_show(label);
 
@@ -716,7 +722,7 @@ void SetCustomProfileDialog(GtkWindow *parent,PhotoPrint_State &state,Layout_Ima
 
 	if(target==CM_COLOURDEVICE_NONE)
 	{
-		label=gtk_label_new("Can't show a colour managed\npreview unless you choose\na Default RGB or Monitor profile\nin the Options->Colour Management\ndialog!");
+		label=gtk_label_new(_("Can't show a colour managed\npreview unless you choose\na Default RGB or Monitor profile\nin the Options->Colour Management\ndialog!"));
 		gtk_table_attach_defaults(GTK_TABLE(table),label,1,2,1,2);
 		gtk_widget_show(label);
 	}
@@ -741,7 +747,7 @@ void SetCustomProfileDialog(GtkWindow *parent,PhotoPrint_State &state,Layout_Ima
 	IS_TYPE t=IS_TYPE(STRIP_ALPHA(is->type));
 	if(is->GetEmbeddedProfile())
 	{
-		GtkWidget *tmp=gtk_label_new("Warning: Image already has an embedded profile\nAssigning a new one will over-ride it!");
+		GtkWidget *tmp=gtk_label_new(_("Warning: Image already has an embedded profile\nAssigning a new one will over-ride it!"));
 		gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox),tmp,FALSE,FALSE,5);
 		gtk_widget_show(tmp);
 	}
@@ -758,7 +764,7 @@ void SetCustomProfileDialog(GtkWindow *parent,PhotoPrint_State &state,Layout_Ima
 
 	st.profselector=outputprof;
 
-	GtkWidget *profactive=gtk_check_button_new_with_label("Assign Profile:");
+	GtkWidget *profactive=gtk_check_button_new_with_label(_("Assign Profile:"));
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(profactive),(oldcustomprofile!=NULL));
 	g_signal_connect(G_OBJECT(profactive),"toggled",G_CALLBACK(refreshprofiledialog),&st);
 	gtk_table_attach_defaults(GTK_TABLE(table),profactive,0,1,0,1);
@@ -766,8 +772,7 @@ void SetCustomProfileDialog(GtkWindow *parent,PhotoPrint_State &state,Layout_Ima
 
 	st.profenabled=profactive;
 
-	// Use a custom widget here for setting the intent.
-	label=gtk_label_new("Rendering intent:");
+	label=gtk_label_new(_("Rendering intent:"));
 	gtk_table_attach_defaults(GTK_TABLE(table),label,0,1,1,2);
 	gtk_widget_show(label);
 
