@@ -1,7 +1,7 @@
 /*
  * imagesource_rotate.cpp - filter to rotate and image through
  * 0, 90, 180 or 270 degrees.
- * supports random access, even if source image doesn't.
+ * supports random access, unless source image doesn't, and rotation is zero.
  *
  * Copyright (c) 2004 by Alastair M. Robinson
  * Distributed under the terms of the GNU General Public License -
@@ -37,6 +37,8 @@ ISDataType *ImageSource_Rotate::GetRow(int row)
 	switch(rotation)
 	{
 		case 0:
+			// FIXME - if source doesn't support random access, image needs
+			// to be cached.
 			return(source->GetRow(row));
 			break;
 		case 90:
@@ -99,6 +101,73 @@ ISDataType *ImageSource_Rotate::GetRow(int row)
 			return(spanbuffer+row*samplesperrow);		
 			break;
 		case 180:
+			// FIXME: support full-image caching here...
+
+			if((row<spanfirstrow) || (row>=(spanfirstrow+spanrows)))
+			{
+				spanfirstrow=row;
+
+				firstrow=row;
+				lastrow=row+spanrows;
+				if(lastrow>height)
+					lastrow=height;
+
+				for(int y=0;y<height;++y)
+				{
+					cerr << "Getting source row: " << y << endl;
+					src=source->GetRow(y);
+					dst=spanbuffer+((height-1)-y)*samplesperrow;
+					cerr << "Found spanbuffer row: " << y << endl;
+					switch(samplesperpixel)
+					{
+						case 1:
+							cerr << "1 sample per pixel - copying row..." << endl;
+							for(x=0;x<width;++x)
+							{
+								int sx=(width-1)-x;
+								c=src[sx];
+								dst[x]=c;
+							}
+							break;
+						case 3:
+							cerr << "3 samples per pixel - copying row..." << endl;
+							for(x=0;x<width;++x)
+							{
+								int sx=(width-1)-x;
+								c=src[sx*3];
+								dst[x*3]=c;
+								c=src[sx*3+1];
+								dst[x*3+1]=c;
+								c=src[sx*3+2];
+								dst[x*3+2]=c;
+							}
+							break;
+						case 4:
+							cerr << "4 samples per pixel - copying row..." << endl;
+							for(x=0;x<width;++x)
+							{
+								int sx=(width-1)-x;
+								c=src[sx*4];
+								dst[x*4]=c;
+								c=src[sx*4+1];
+								dst[x*4+1]=c;
+								c=src[sx*4+2];
+								dst[x*4+2]=c;
+								c=src[sx*4+3];
+								dst[x*4+3]=c;
+							}
+							break;
+						default:
+							throw "Rotate: Only 1, 3 or 4 samples per pixel are currently supported";
+							break;
+					}
+				}
+			}
+			row-=spanfirstrow;
+			return(spanbuffer+row*samplesperrow);		
+			break;
+			
+#if 0
 			src=source->GetRow((height-1)-row);
 			dst=rowbuffer;
 
@@ -142,6 +211,7 @@ ISDataType *ImageSource_Rotate::GetRow(int row)
 					throw "Rotate: Only 1, 3 or 4 samples per pixel are currently supported";
 					break;
 			}
+#endif
 			break;
 		case 270:
 			if((row<spanfirstrow) || (row>=(spanfirstrow+spanrows)))
@@ -232,19 +302,30 @@ ImageSource_Rotate::ImageSource_Rotate(ImageSource *source,int rotation,int span
 
 	if(!source->randomaccess)
 	{
-		cerr << "Rotate: source doesn't support random access - caching entire image" << endl;
-		if(source->width<source->height)
-			this->spanrows=source->height;
-		else
-			this->spanrows=source->width;
+		switch(rotation)
+		{
+			case 0:
+			case 180:
+				cerr << "Rotate: source doesn't support random access - caching entire image" << endl;
+				this->spanrows=source->height;
+				break;
+			case 90:
+			case 270:
+				cerr << "Rotate: source doesn't support random access - caching entire image" << endl;
+				this->spanrows=source->width;
+				break;
+		}
 	}
 	spanfirstrow=-this->spanrows-1;
 	samplesperrow=width*samplesperpixel;
 
-	if((rotation==90) || (rotation==270))
+	if((rotation==90) || (rotation==270) || (rotation==180))
 		spanbuffer=(ISDataType *)malloc(this->spanrows*(sizeof(ISDataType)*samplesperrow));
 	else
 		MakeRowBuffer();
 	currentrow=-1;
-	randomaccess=true;
+	if(rotation==0)
+		randomaccess=source->randomaccess;
+	else
+		randomaccess=true;
 }
