@@ -9,7 +9,8 @@ enum IS_ScalingQuality
 	IS_SCALING_NEARESTNEIGHBOUR,
 	IS_SCALING_BILINEAR,
 	IS_SCALING_LANCZOSSINC,
-	IS_SCALING_MAX
+	IS_SCALING_MAX,
+	IS_SCALING_DOWNSAMPLE	// An extra entry used for high-quality image reduction.
 };
 
 struct IS_ScalingQualityDescription
