@@ -15,6 +15,6 @@
 
 #include "imagesource/imagesource.h"
 
-GdkPixbuf *pixbuf_from_imagesource(ImageSource *is);
+GdkPixbuf *pixbuf_from_imagesource(ImageSource *is,int redbg8=255,int greenbg8=255,int bluebg8=255);
 
 #endif
