@@ -297,25 +297,9 @@ pp_layout_single_pageview_expose( GtkWidget      *widget,
 	pageview->top=(widget->allocation.height-pageview->height)/2;
 	pageview->left=(widget->allocation.width-pageview->width)/2;
 
-	gdk_draw_rectangle (widget->window,
-		widget->style->light_gc[widget->state],TRUE,
-		pageview->left,pageview->top,
-		pageview->width,pageview->height);
-
 	pageview->scale=pageview->width;
 	pageview->scale/=pageview->layout->pagewidth;
 
-
-	pageview->layout->GetImageableArea();
-
-	LayoutRectangle sr(pageview->layout->leftmargin,pageview->layout->topmargin,
-		pageview->layout->imageablewidth,pageview->layout->imageableheight);
-	sr.Scale(pageview->scale);
-
-	gdk_draw_rectangle (widget->window,
-		widget->style->mid_gc[widget->state],FALSE,
-		pageview->left+sr.x,pageview->top+sr.y,sr.w,sr.h);
-
 	pageview->layout->DrawPreview(widget,pageview->left,pageview->top,pageview->width,pageview->height);
 
 	return FALSE;
