@@ -12,6 +12,8 @@ class PrintOutput : public ConfigDB, public PrinterQueues
 	public:
 	PrintOutput(ConfigFile *inif,char *section);
 	Consumer *GetConsumer();
+	void DBToQueues();
+	void QueuesToDB();
 	private:
 	static ConfigTemplate Template[];
 	char *str2;
